@@ -1,12 +1,12 @@
 from django import template
 from django.utils import simplejson
 
-
-from javascript_settings.configuration_builder import DEFAULT_CONFIGURATION_BUILDER
-
+from javascript_settings.configuration_builder import \
+    DEFAULT_CONFIGURATION_BUILDER
 
 register = template.Library()
 
+
 @register.tag(name='javascript_settings')
 def do_javascript_settings(parser, token):
     """
@@ -19,7 +19,6 @@ class JavascriptConfigurationNode(template.Node):
     """
         Represents a node that renders JavaScript configuration.
     """
-
     def __init__(self):
         pass
 
@@ -28,5 +27,5 @@ class JavascriptConfigurationNode(template.Node):
             Renders JS configuration.
         """
         return 'var configuration = ' + simplejson.dumps(
-                DEFAULT_CONFIGURATION_BUILDER.get_configuration()) + ';'
-
+            DEFAULT_CONFIGURATION_BUILDER.get_configuration()
+        ) + ';'
